import { Component, Element, h, Host, Prop } from '@stencil/core';
import { createColorStyles } from '../../utils/color';
import { isSafeNumber, isString } from '../../utils/type-guards';
const defaultValues = {
    value: -1,
    radius: 100,
    color: '',
    stroke: 10,
    shape: 'butt',
};
export class ProgressCircleComponent {
    constructor() {
        /** The progress value in percent. Use -1 or undefined for indeterminate loading animation. */
        this.value = defaultValues.value;
        /** The circle radius in percent. The default size is 200px (radius 100px) but scaled to 100% of parent. */
        this.radius = defaultValues.radius;
        /** The circle color. Use predefined colors like `info`, `success`, `warning` or `danger` or a custom color like `#123456` or `yellow`. */
        this.color = defaultValues.color;
        /** The line width in percent. If stroke >= radius then circle is filled (pie). */
        this.stroke = defaultValues.stroke;
        /** The line cap shape. For example: `round`. */
        this.shape = defaultValues.shape;
    }
    isIndeterminate() {
        return this.value < 0;
    }
    getValidValues() {
        return {
            value: isSafeNumber(this.value) ? this.value : defaultValues.value,
            radius: isSafeNumber(this.radius) ? this.radius : defaultValues.radius,
            stroke: isSafeNumber(this.stroke) ? this.stroke : defaultValues.stroke,
            color: isString(this.color) ? this.color : defaultValues.color,
            shape: isString(this.shape) ? this.shape : defaultValues.shape,
        };
    }
    render() {
        const props = this.getValidValues();
        const radius = props.radius > 100 ? 100 : props.radius;
        const stroke = props.stroke > radius ? radius : props.stroke;
        const normalizedRadius = radius - stroke / 2;
        const circumference = normalizedRadius * 2 * Math.PI;
        const offset = circumference - (props.value / 100) * circumference;
        return (h(Host, { class: {
                indeterminate: this.isIndeterminate(),
            } },
            h("svg", { viewBox: "0 0 200 200", width: "100%", height: "100%", style: Object.assign({ '--circle-dash': `${circumference}`, '--circle-dash-inv': `${-circumference + 1}` }, createColorStyles(props.color, true)) },
                h("circle", { "stroke-dashoffset": offset, "stroke-width": stroke, "stroke-linecap": props.shape, fill: "transparent", r: normalizedRadius, cx: "100", cy: "100" }))));
    }
    static get is() { return "ui-progress-circle"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["progress-circle.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["progress-circle.css"]
    }; }
    static get properties() { return {
        "value": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The progress value in percent. Use -1 or undefined for indeterminate loading animation."
            },
            "attribute": "value",
            "reflect": false,
            "defaultValue": "defaultValues.value"
        },
        "radius": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The circle radius in percent. The default size is 200px (radius 100px) but scaled to 100% of parent."
            },
            "attribute": "radius",
            "reflect": false,
            "defaultValue": "defaultValues.radius"
        },
        "color": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The circle color. Use predefined colors like `info`, `success`, `warning` or `danger` or a custom color like `#123456` or `yellow`."
            },
            "attribute": "color",
            "reflect": false,
            "defaultValue": "defaultValues.color"
        },
        "stroke": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The line width in percent. If stroke >= radius then circle is filled (pie)."
            },
            "attribute": "stroke",
            "reflect": false,
            "defaultValue": "defaultValues.stroke"
        },
        "shape": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "SvgLineCap",
                "resolved": "\"butt\" | \"inherit\" | \"round\" | \"square\"",
                "references": {
                    "SvgLineCap": {
                        "location": "local"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The line cap shape. For example: `round`."
            },
            "attribute": "shape",
            "reflect": false,
            "defaultValue": "defaultValues.shape"
        }
    }; }
    static get elementRef() { return "el"; }
}
