import { attachShadow, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
export { setAssetPath } from '@stencil/core/internal/client';

const colors = {
    success: {
        base: '#27ae60',
        contrast: '#ffffff',
    },
    info: {
        base: '#2980b9',
        contrast: '#ffffff',
    },
    warning: {
        base: '#f3d112',
        contrast: '#000000',
    },
    danger: {
        base: '#c0392b',
        contrast: '#ffffff',
    },
};
const createColorStyles = (name, textOnly = false) => {
    const color = colors[name] || { base: name, contrast: 'currentColor' };
    return textOnly
        ? {
            color: color.base,
        }
        : {
            'background-color': color.base,
            'color': color.contrast,
        };
};

const isString = (input) => {
    return typeof input === 'string';
};
const isSafeNumber = (input) => {
    return typeof input === 'number' && !isNaN(input) && isFinite(input);
};

const progressCircleCss = ":host{display:-ms-inline-flexbox;display:inline-flex;overflow:hidden;width:100%;height:100%}:host svg{width:100%;height:100%}:host circle{-webkit-transition:stroke-dashoffset 300ms;transition:stroke-dashoffset 300ms;-webkit-transform:rotate(-90deg);transform:rotate(-90deg);-webkit-transform-origin:50% 50%;transform-origin:50% 50%;stroke-dasharray:var(--circle-dash);stroke:currentColor}:host(.indeterminate) svg{-webkit-animation:rotate 1.1s linear infinite;animation:rotate 1.1s linear infinite}:host(.indeterminate) svg circle{stroke-dashoffset:0;-webkit-animation:dash 1.8s ease-in-out infinite;animation:dash 1.8s ease-in-out infinite}:host(.no-animation) circle{-webkit-transition:none !important;transition:none !important}@-webkit-keyframes rotate{100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@keyframes rotate{100%{-webkit-transform:rotate(360deg);transform:rotate(360deg)}}@-webkit-keyframes dash{0%{stroke-dasharray:0 var(--circle-dash);stroke-dashoffset:0}100%{stroke-dasharray:var(--circle-dash) var(--circle-dash);stroke-dashoffset:var(--circle-dash-inv)}}@keyframes dash{0%{stroke-dasharray:0 var(--circle-dash);stroke-dashoffset:0}100%{stroke-dasharray:var(--circle-dash) var(--circle-dash);stroke-dashoffset:var(--circle-dash-inv)}}";

const defaultValues = {
    value: -1,
    radius: 100,
    color: '',
    stroke: 10,
    shape: 'butt',
};
const ProgressCircleComponent = class extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        attachShadow(this);
        /** The progress value in percent. Use -1 or undefined for indeterminate loading animation. */
        this.value = defaultValues.value;
        /** The circle radius in percent. The default size is 200px (radius 100px) but scaled to 100% of parent. */
        this.radius = defaultValues.radius;
        /** The circle color. Use predefined colors like `info`, `success`, `warning` or `danger` or a custom color like `#123456` or `yellow`. */
        this.color = defaultValues.color;
        /** The line width in percent. If stroke >= radius then circle is filled (pie). */
        this.stroke = defaultValues.stroke;
        /** The line cap shape. For example: `round`. */
        this.shape = defaultValues.shape;
    }
    isIndeterminate() {
        return this.value < 0;
    }
    getValidValues() {
        return {
            value: isSafeNumber(this.value) ? this.value : defaultValues.value,
            radius: isSafeNumber(this.radius) ? this.radius : defaultValues.radius,
            stroke: isSafeNumber(this.stroke) ? this.stroke : defaultValues.stroke,
            color: isString(this.color) ? this.color : defaultValues.color,
            shape: isString(this.shape) ? this.shape : defaultValues.shape,
        };
    }
    render() {
        const props = this.getValidValues();
        const radius = props.radius > 100 ? 100 : props.radius;
        const stroke = props.stroke > radius ? radius : props.stroke;
        const normalizedRadius = radius - stroke / 2;
        const circumference = normalizedRadius * 2 * Math.PI;
        const offset = circumference - (props.value / 100) * circumference;
        return (h(Host, { class: {
                indeterminate: this.isIndeterminate(),
            } }, h("svg", { viewBox: "0 0 200 200", width: "100%", height: "100%", style: Object.assign({ '--circle-dash': `${circumference}`, '--circle-dash-inv': `${-circumference + 1}` }, createColorStyles(props.color, true)) }, h("circle", { "stroke-dashoffset": offset, "stroke-width": stroke, "stroke-linecap": props.shape, fill: "transparent", r: normalizedRadius, cx: "100", cy: "100" }))));
    }
    get el() { return this; }
    static get style() { return progressCircleCss; }
};

const UiProgressCircle = /*@__PURE__*/proxyCustomElement(ProgressCircleComponent, [1,"ui-progress-circle",{"value":[2],"radius":[2],"color":[1],"stroke":[2],"shape":[1]}]);
const defineCustomElements = (opts) => {
  if (typeof customElements !== 'undefined') {
    [
      UiProgressCircle
    ].forEach(cmp => {
      if (!customElements.get(cmp.is)) {
        customElements.define(cmp.is, cmp, opts);
      }
    });
  }
};

export { UiProgressCircle, defineCustomElements };
